from django.contrib import admin

from ...widgets.layout.Section.admin import SectionAdmin
from ...widgets.nav.admin import NavigationItemInline
from .forms import HeaderHeroAddForm, HeaderHeroChangeForm
from .models import HeaderHero


class HeaderHeroNavigationItemInline(NavigationItemInline):
    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.filter(section_type="header")


@admin.register(HeaderHero)
class HeaderHeroAdmin(SectionAdmin):
    add_form = HeaderHeroAddForm
    form = HeaderHeroChangeForm
    model = HeaderHero
    inlines = [HeaderHeroNavigationItemInline]

    fieldsets = [
        (None, {"fields": ["section_instance", "section_version"]}),
        (
            "HEADER SETTINGS",
            {
                "classes": ("collapse",),
                "fields": [
                    "header_background",
                    "logo_version",
                    "theme_toggler",
                ],
            },
        ),
        (
            "HERO CONTENT",
            {
                "classes": ("collapse",),
                "fields": [
                    "hero_heading",
                    "hero_sub_heading",
                    "hero_paragraph",
                    "hero_image",
                    "hero_button_text",
                    "hero_button_href",
                ],
            },
        ),
    ]
