from rest_framework import serializers

from .models import NavigationItem


class NavigationItemSerializer(serializers.ModelSerializer):
    children = serializers.SerializerMethodField()

    class Meta:
        model = NavigationItem
        exclude = [
            "header_section",
            "footer_section",
            "aside_section",
            "section_type",
        ]

    def get_children(self, obj):
        if obj.children.exists():
            # Pass is_child=True in context when serializing children
            serializer = NavigationItemSerializer(
                obj.children.all(), many=True, context={"is_child": True}
            )
            return serializer.data
        return None

    def to_representation(self, instance):
        # Only filter out nested items at the root level
        if not self.context.get("is_child", False) and instance.type == "nested":
            return None
        return super().to_representation(instance)
